# DIRECT - A Global Optimization Algorithm

Function   : Direct Version 4.0

Written by : Dan Finkel (definkel@unity.ncsu.edu)

Created on : 01/27/2003

Last Update: 06/21/2004

To download the original unmodified algorithm please visit http://www4.ncsu.edu/~ctk/Finkel_Direct/ 
and for more information see http://www4.ncsu.edu/~ctk/Finkel_Direct/DirectUserGuide_pdf.pdf
